<?php declare(strict_types=1);

namespace App\Entity;

/**
 * Trait CameraTrait
 *
 * Shared columns for camera, and previously_owned_camera tables
 *
 * @package App\Entity
 */
trait CameraTrait
{
	use PurchasePriceTrait;

	/**
	 * @var CameraType
	 *
	 * @ORM\ManyToOne(targetEntity="CameraType")
	 * @ORM\JoinColumns({
	 *   @ORM\JoinColumn(name="type_id", referencedColumnName="id")
	 * })
	 */
	private $type;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="brand", type="string", length=64, nullable=false)
	 */
	private $brand;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="mount", type="string", length=32, nullable=false)
	 */
	private $mount;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="model", type="string", length=255, nullable=false)
	 */
	private $model;

	/**
	 * @var boolean
	 *
	 * @ORM\Column(name="is_digital", type="boolean", nullable=false)
	 */
	private $isDigital;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="crop_factor", type="decimal", precision=10, scale=0, nullable=false)
	 */
	private $cropFactor = '1.0';

	/**
	 * @var boolean
	 *
	 * @ORM\Column(name="is_working", type="boolean", nullable=false)
	 */
	private $isWorking;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="notes", type="text", nullable=true)
	 */
	private $notes;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="serial", type="string", length=20, nullable=false)
	 */
	private $serial;

	/**
	 * @var boolean
	 *
	 * @ORM\Column(name="formerly_owned", type="boolean", nullable=false)
	 */
	private $formerlyOwned = false;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="purchase_price", type="money", nullable=true)
	 */
	private $purchasePrice;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="battery_type", type="string", nullable=true)
	 */
	private $batteryType;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="film_format", type="string", nullable=true)
	 */
	private $filmFormat = '135';

	/**
	 * @var boolean
	 *
	 * @ORM\Column(name="received", type="boolean", nullable=true)
	 */
	private $received = false;

	/**
	 * Get id
	 *
	 * @return integer
	 */
	public function getId(): int
	{
		return $this->id;
	}

	/**
	 * Set type
	 *
	 * @param CameraType $type
	 *
	 * @return self
	 */
	public function setType(CameraType $type = null): self
	{
		$this->type = $type;

		return $this;
	}

	/**
	 * Get type
	 *
	 * @return CameraType
	 */
	public function getType(): ?CameraType
	{
		return $this->type;
	}

	/**
	 * Set brand
	 *
	 * @param string $brand
	 *
	 * @return self
	 */
	public function setBrand($brand): self
	{
		$this->brand = $brand;

		return $this;
	}

	/**
	 * Get brand
	 *
	 * @return string
	 */
	public function getBrand(): ?string
	{
		return $this->brand;
	}

	/**
	 * Set mount
	 *
	 * @param string $mount
	 *
	 * @return self
	 */
	public function setMount($mount): self
	{
		$this->mount = $mount;

		return $this;
	}

	/**
	 * Get mount
	 *
	 * @return string
	 */
	public function getMount():  ?string
	{
		return $this->mount;
	}

	/**
	 * Set model
	 *
	 * @param string $model
	 *
	 * @return self
	 */
	public function setModel($model): self
	{
		$this->model = $model;

		return $this;
	}

	/**
	 * Get model
	 *
	 * @return string
	 */
	public function getModel(): ?string
	{
		return $this->model;
	}

	/**
	 * Set isDigital
	 *
	 * @param boolean $isDigital
	 *
	 * @return self
	 */
	public function setIsDigital($isDigital): self
	{
		$this->isDigital = $isDigital;

		return $this;
	}

	/**
	 * Get isDigital
	 *
	 * @return boolean
	 */
	public function getIsDigital(): ?bool
	{
		return $this->isDigital;
	}

	/**
	 * Set cropFactor
	 *
	 * @param string $cropFactor
	 *
	 * @return self
	 */
	public function setCropFactor($cropFactor): self
	{
		$this->cropFactor = $cropFactor;

		return $this;
	}

	/**
	 * Get cropFactor
	 *
	 * @return string
	 */
	public function getCropFactor(): string
	{
		return $this->cropFactor;
	}

	/**
	 * Set isWorking
	 *
	 * @param boolean $isWorking
	 *
	 * @return self
	 */
	public function setIsWorking($isWorking): self
	{
		$this->isWorking = $isWorking;

		return $this;
	}

	/**
	 * Get isWorking
	 *
	 * @return boolean
	 */
	public function getIsWorking(): ?bool
	{
		return $this->isWorking;
	}

	/**
	 * Set notes
	 *
	 * @param string $notes
	 *
	 * @return self
	 */
	public function setNotes($notes): self
	{
		$this->notes = $notes;

		return $this;
	}

	/**
	 * Get notes
	 *
	 * @return string
	 */
	public function getNotes(): ?string
	{
		return $this->notes;
	}

	/**
	 * Set serial
	 *
	 * @param string $serial
	 *
	 * @return self
	 */
	public function setSerial($serial): self
	{
		$this->serial = $serial;

		return $this;
	}

	/**
	 * Get serial
	 *
	 * @return string
	 */
	public function getSerial(): ?string
	{
		return $this->serial;
	}

	/**
	 * Set formerlyOwned
	 *
	 * @param boolean $formerlyOwned
	 *
	 * @return self
	 */
	public function setFormerlyOwned($formerlyOwned): self
	{
		$this->formerlyOwned = $formerlyOwned;

		return $this;
	}

	/**
	 * Get formerlyOwned
	 *
	 * @return boolean
	 */
	public function getFormerlyOwned(): ?bool
	{
		return $this->formerlyOwned;
	}

	/**
	 * Set batteryType
	 *
	 * @param string $batteryType
	 *
	 * @return self
	 */
	public function setBatteryType($batteryType): self
	{
		$this->batteryType = $batteryType;

		return $this;
	}

	/**
	 * Get batteryType
	 *
	 * @return string
	 */
	public function getBatteryType(): ?string
	{
		return $this->batteryType;
	}

	/**
	 * Set filmFormat
	 *
	 * @param string $filmFormat
	 *
	 * @return self
	 */
	public function setFilmFormat($filmFormat): self
	{
		$this->filmFormat = $filmFormat;

		return $this;
	}

	/**
	 * Get filmFormat
	 *
	 * @return string
	 */
	public function getFilmFormat(): string
	{
		return $this->filmFormat;
	}

	/**
	 * Set received
	 *
	 * @param boolean $received
	 *
	 * @return self
	 */
	public function setReceived($received): self
	{
		$this->received = $received;

		return $this;
	}

	/**
	 * Get received
	 *
	 * @return boolean
	 */
	public function getReceived(): bool
	{
		return $this->received;
	}

}
