<?php declare(strict_types=1);

namespace App\Entity;

use Doctrine\ORM\Mapping as ORM;

/**
 * Camera
 *
 * @ORM\Table(name="film", schema="camera")
 * @ORM\Entity
 */
class Film {

	/**
	 * @var integer
	 *
	 * @ORM\Id
	 * @ORM\Column(name="id", type="integer", nullable=false)
	 * @ORM\GeneratedValue(strategy="IDENTITY")
	 */
	private $id;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="brand", type="string", nullable=false)
	 */
	private $brand;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="product_line", type="string", nullable=false)
	 */
	private $product_line;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="film_name", type="string", nullable=false)
	 */
	private $film_name;

	/**
	 * @var int
	 *
	 * @ORM\Column(name="film_speed_asa", type="integer", nullable=false)
	 */
	private $film_speed_asa;

	/**
	 * @var int
	 *
	 * @ORM\Column(name="film_speed_din", type="integer", nullable=false)
	 */
	private $film_speed_din;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="film_format", type="string", nullable=false)
	 */
	private $film_format;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="film_base", type="string", nullable=false, options={"default"="Cellulose Triacetate"})
	 */
	private $film_base;

	/**
	 * @var int
	 *
	 * @ORM\Column(name="unused_rolls", type="integer", nullable=false, options={"default"=0})
	 */
	private $unused_rolls;

	/**
	 * @var int
	 *
	 * @ORM\Column(name="developed_rolls", type="integer", nullable=false, options={"default"=0})
	 */
	private $developed_rolls;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="chemistry", type="string", nullable=false, options={"default"="C-41"})
	 */
	private $chemistry;

	/**
	 * @var string
	 *
	 * @ORM\Column(name="notes", type="text", nullable=true)
	 */
	private $notes;

	/**
	 * @return string
	 */
	public function getBrand(): string
	{
		return $this->brand;
	}

	/**
	 * @param string $brand
	 * @return self
	 */
	public function setBrand(string $brand): self
	{
		$this->brand = $brand;
		return $this;
	}

	/**
	 * @return string
	 */
	public function getProductLine(): string
	{
		return $this->product_line;
	}

	/**
	 * @param string $product_line
	 * @return self
	 */
	public function setProductLine(string $product_line): self
	{
		$this->product_line = $product_line;
		return $this;
	}

	/**
	 * @return string
	 */
	public function getFilmName(): string
	{
		return $this->film_name;
	}

	/**
	 * @param string $film_name
	 * @return self
	 */
	public function setFilmName(string $film_name): self
	{
		$this->film_name = $film_name;
		return $this;
	}

	/**
	 * @return int
	 */
	public function getFilmSpeedAsa(): int
	{
		return $this->film_speed_asa;
	}

	/**
	 * @param int $film_speed_asa
	 * @return self
	 */
	public function setFilmSpeedAsa(int $film_speed_asa): self
	{
		$this->film_speed_asa = $film_speed_asa;
		return $this;
	}

	/**
	 * @return int
	 */
	public function getFilmSpeedDin(): int
	{
		return $this->film_speed_din;
	}

	/**
	 * @param int $film_speed_din
	 * @return self
	 */
	public function setFilmSpeedDin(int $film_speed_din): self
	{
		$this->film_speed_din = $film_speed_din;
		return $this;
	}

	/**
	 * @return string
	 */
	public function getFilmFormat(): string
	{
		return $this->film_format;
	}

	/**
	 * @param string $film_format
	 * @return self
	 */
	public function setFilmFormat(string $film_format): self
	{
		$this->film_format = $film_format;
		return $this;
	}

	/**
	 * @return string
	 */
	public function getFilmBase(): string
	{
		return $this->film_base;
	}

	/**
	 * @param string $film_base
	 * @return self
	 */
	public function setFilmBase(string $film_base): self
	{
		$this->film_base = $film_base;
		return $this;
	}

	/**
	 * @return int
	 */
	public function getUnusedRolls(): int
	{
		return $this->unused_rolls;
	}

	/**
	 * @param int $unused_rolls
	 * @return self
	 */
	public function setUnusedRolls(int $unused_rolls): self
	{
		$this->unused_rolls = $unused_rolls;
		return $this;
	}

	/**
	 * @return int
	 */
	public function getDevelopedRolls(): int
	{
		return $this->developed_rolls;
	}

	/**
	 * @param int $developed_rolls
	 * @return self
	 */
	public function setDevelopedRolls(int $developed_rolls): self
	{
		$this->developed_rolls = $developed_rolls;
		return $this;
	}

	/**
	 * @return string
	 */
	public function getChemistry(): string
	{
		return $this->chemistry;
	}

	/**
	 * @param string $chemistry
	 * @return self
	 */
	public function setChemistry(string $chemistry): self
	{
		$this->chemistry = $chemistry;
		return $this;
	}

	/**
	 * @return string
	 */
	public function getNotes(): ?string
	{
		return $this->notes;
	}

	/**
	 * @param string $notes
	 * @return self
	 */
	public function setNotes(string $notes): self
	{
		$this->notes = $notes;
		return $this;
	}
}
